#
# spec file for package perl-TheSchwartz
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-TheSchwartz
Version:        1.12
Release:        lp151.2.1
%define cpan_name TheSchwartz
Summary:        reliable job queue
License:        Artistic-1.0 or GPL-1.0+
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/TheSchwartz/
Source:         http://www.cpan.org/authors/id/J/JF/JFEARN/%{cpan_name}-%{version}.tar.gz
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Data::ObjectDriver) >= 0.04
BuildRequires:  perl(Module::Build)
Requires:       perl(Data::ObjectDriver) >= 0.04
%{perl_requires}

%description
TheSchwartz is a reliable job queue system. Your application can put jobs
into the system, and your worker processes can pull jobs from the queue
atomically to perform. Failed jobs can be left in the queue to retry later.

_Abilities_ specify what jobs a worker process can perform. Abilities are
the names of 'TheSchwartz::Worker' sub-classes, as in the synopsis: the
'MyWorker' class name is used to specify that the worker script can perform
the job. When using the 'TheSchwartz' client's 'work' functions, the
class-ability duality is used to automatically dispatch to the proper class
to do the actual work.

TheSchwartz clients will also prefer to do jobs for unused abilities before
reusing a particular ability, to avoid exhausting the supply of one kind of
job while jobs of other types stack up.

Some jobs with high setup times can be performed more efficiently if a
group of related jobs are performed together. TheSchwartz offers a facility
to _coalesce_ jobs into groups, which a properly constructed worker can
find and perform at once. For example, if your worker were delivering
email, you might store the domain name from the recipient's address as the
coalescing value. The worker that grabs that job could then batch deliver
all the mail for that domain once it connects to that domain's mail server.

%prep
%setup -q -n %{cpan_name}-%{version}
find . -type f -print0 | xargs -0 chmod 644

%build
%{__perl} Build.PL installdirs=vendor
./Build build flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install destdir=%{buildroot} create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc CHANGES doc extras README.md server

%changelog
* Tue Apr 14 2015 coolo@suse.com
- updated to 1.12
  see /usr/share/doc/packages/perl-TheSchwartz/CHANGES
  1.12 Mon Mar 30 2015
  - Fix replace_job hanging & postgresql issues. RT #65712
  - Add strict_remove_ability to prevent auto resetting of abilities.
  - Stricter job check. https://github.com/jfearn/TheSchwartz/pull/1
  - Add accessor methods for strict_remove_ability.
  - Add debug message to mark_database_as_dead. RT #102510
  1.11 Mon Nov 03 2014
  - Move from Make to Module::Build
  - Remove inc & autobuild
  - Add perltidyrc and run over all perl files.
  - Add perlcritic test & fix errors
  - Add Test::Spelling and fix all spelling errors in POD. RT #89165
  - Reorder jobs when prioritize is set. RT #99075
  - Fix wrong return precedence. RT #87222
  - Fix get_server_time for Oracle. # RT #58049
  - Support Data::ObjectDriver->get_dbh. RT #50022
  - Use sort by jobid on selects. RT #34843
  - Added floor methods to limit priortity job selection. RT #50842
  - Add batch_size methods to expose FIND_JOB_BATCH_SIZE. RT #72815
  - Add run_after param to decline. RT #60797
  - Add jobid param to list_jobs.
* Fri Apr 29 2011 coolo@opensuse.org
- updated to 1.10
  - Add $job->declined method for workers to be able to decline handling
    a job at this time.
  - Added $client->grab_and_work_on($handle) to securely work on a job
    you know the handle of. Yann Kerherve (yannk@cpan.org)
  - Fixed docs and tests (miyagawa, athomason, simonw)
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Fri Nov  6 2009 dmueller@suse.de
- Initial package (1.07)
